@@ -42,11 +42,17 @@ class Excel:
         :param sheet_name:
         :return:
         """
+
+        if isinstance(cell, str):
+            cell = self.get_cell(cell)
+        elif not isinstance(cell, tuple) and not isinstance(cell, list):
+            raise TypeError('cell must be a tuple or string')
+
         sheet_name = sheet_name if sheet_name else self.sheet_name
         ws = self.wb[sheet_name]
-        value = ws[cell].value
+        value = ws.cell(cell[0], cell[1]).value
         value = '' if value is None else value
-        value = str(value).strip()
+        value = str(value).strip().replace('\xa0', ' ')
         return value
 
     def get_color(self, cell) -> ColorObject:
@@ -64,31 +70,46 @@ class Excel:
 
         return ColorObject(hex_color, rgb_color, color_name)
 
-    def read_range(self, cell_1, cell_2, sheet_name=None) -> list:
+    def read_range(self, start, end, sheet_name=None, remove_empty=False) -> list:
         """
         Reads a range of cells
-        :param cell_1:
-        :param cell_2:
+        :param start:
+        :param end:
         :param sheet_name:
+        :param remove_empty:
         :return:
         """
+        data = []
+
         sheet_name = sheet_name if sheet_name else self.sheet_name
 
-        var = self.get_cell(cell_1)
-        var2 = self.get_cell(cell_2)
+        rc_start = self.get_cell(start)
+        rc_end = self.get_cell(end)
 
-        ws = self.wb[sheet_name]
-
-        data = []
-        for _ in range(var[0], var2[0] + 1):
+        for row in range(rc_start[0], rc_end[0] + 1):
             temp = []
-            for __ in range(var[1], var2[1] + 1):
-                temp.append(ws.cell(_, __).value)
+            for col in range(rc_start[1], rc_end[1] + 1):
+                temp.append(self.cell((row, col), sheet_name))
 
-            data.append(temp)
+            if remove_empty:
+                if not all([not _ for _ in temp]):
+                    data.append(temp)
+            else:
+                data.append(temp)
 
         return data
 
+    def read_all(self, sheet_name=None, remove_empty=False) -> list:
+        """
+        Reads all cells in a sheet
+        :param sheet_name:
+        :param remove_empty:
+        :return:
+        """
+        sheet_name = sheet_name if sheet_name else self.sheet_name
+        return self.read_range('A1', self.get_last(), sheet_name, remove_empty)
+
+    # Still buggy
     def read_indefinitely(self, start_cell: str, num_of_columns: int, num_of_rows=None, steps: int = 1) -> list:
         """
         Reads a range of cells indefinitely
@@ -138,7 +159,7 @@ class Excel:
         xy = coordinate_from_string(cell)
         col = column_index_from_string(xy[0])
         row = xy[1]
-        return col, row
+        return row, col
 
     @staticmethod
     def get_cell_name(row, column) -> str:
